==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/QGpGuiMath/src/CurveBrowserCut.h <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-02
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef CURVEBROWSERCUT_H
#define CURVEBROWSERCUT_H

#include <QGpGuiTools.h>
#include "ui_CurveBrowserCut.h"
#include "QGpGuiMathDLLExport.h"

namespace QGpGuiMath {

class QGPGUIMATH_EXPORT CurveBrowserCut : public Dialog, public Ui::CurveBrowserCut
{
  Q_OBJECT
public:
  CurveBrowserCut(QWidget * parent=nullptr);

  void setCurveLimits(double min, double max) {_curveMin=min; _curveMax=max;}
  void setAxisNames(QString linearName, QString inversedName);
private slots:
  void on_inversedBut_toggled(bool);
  void on_autoMin_clicked();
  void on_autoMax_clicked();
private:
  double _curveMin, _curveMax;
};

} // namespace QGpGuiMath

#endif // CURVEBROWSERCUT_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/QGpGuiMath/src/CurveBrowserCut.h <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-02
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef CURVEBROWSERCUT_H
#define CURVEBROWSERCUT_H

#include <QGpGuiTools.h>
#include "ui_CurveBrowserCut.h"
#include "QGpGuiMathDLLExport.h"

namespace QGpGuiMath {

class QGPGUIMATH_EXPORT CurveBrowserCut : public Dialog, public Ui::CurveBrowserCut
{
  Q_OBJECT
public:
  CurveBrowserCut(QWidget * parent=nullptr);

  void setCurveLimits(double min, double max) {_curveMin=min; _curveMax=max;}
  void setAxisNames(QString linearName, QString inverseName);
private slots:
  void on_inverseBut_toggled(bool);
  void on_autoMin_clicked();
  void on_autoMax_clicked();
private:
  double _curveMin, _curveMax;
};

} // namespace QGpGuiMath

#endif // CURVEBROWSERCUT_H
